@@ -80,6 +80,10 @@ def cwproxy_for(instance, **kw):
         ]
         if len(instances) == 1:
             instance = instances[0]
+        elif len(instances) > 1:
+            raise ValueError(
+                "Found %r configuration entries for %r" % (len(instances), instance)
+            )
     if instance not in cfg:
         raise ValueError("Cannot find a configuration entry for %r" % instance)
 
