@@ -175,13 +175,8 @@ class CWProxyClientTC(CubicWebServerTC):
 
         eid = self.client.rqlio(queries).json()[0][0][0]
         with self.admin_access.client_cnx() as cnx:
-
             user = cnx.entity_from_eid(eid)
             self.assertEqual(md, user.creation_date)
-            self.assertEqual(
-                md.tzinfo.utcoffset(md),
-                user.creation_date.tzinfo.utcoffset(user.creation_date),
-            )
             self.assertEqual(md, user.modification_date)
 
         # actually only check date type is handled, we can't expect a
